@@ -23,17 +23,15 @@
 #include "kxmlguifactory.h"
 #include "kxmlguibuilder.h"
 #include "kactioncollection.h"
+#include "debug.h"
 
 #include <QAction>
 #include <QDir>
 #include <QFile>
 #include <QDomDocument>
-#include <QTextStream>
-#include <QRegExp>
 #include <QPointer>
 #include <QCoreApplication>
 #include <QStandardPaths>
-#include <QDebug>
 
 #include <kauthorized.h>
 #include <klocalizedstring.h>
@@ -101,7 +99,7 @@ KXMLGUIClient::~KXMLGUIClient()
     }
 
     if (d->m_factory) {
-        qWarning() << this << "deleted without having been removed from the factory first. This will leak standalone popupmenus and could lead to crashes.";
+        qCWarning(DEBUG_KXMLGUI) << this << "deleted without having been removed from the factory first. This will leak standalone popupmenus and could lead to crashes.";
         d->m_factory->forgetClient(this);
     }
 
@@ -248,14 +246,14 @@ void KXMLGUIClient::setXMLFile(const QString &_file, bool merge, bool setXMLDoc)
                    QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, _file); // kdelibs4, KF 5.0, caller passes component name
 
         if (allFiles.isEmpty() && !compatFiles.isEmpty()) {
-            qWarning() << "KXMLGUI file found at deprecated location" << compatFiles << "-- please use ${KXMLGUI_INSTALL_DIR} to install this file instead.";
+            qCWarning(DEBUG_KXMLGUI) << "KXMLGUI file found at deprecated location" << compatFiles << "-- please use ${KXMLGUI_INSTALL_DIR} to install this file instead.";
         }
         allFiles += compatFiles;
     }
     if (allFiles.isEmpty() && !_file.isEmpty()) {
         // if a non-empty file gets passed and we can't find it,
         // inform the developer using some debug output
-        qWarning() << "cannot find .rc file" << _file << "for component" << componentName();
+        qCWarning(DEBUG_KXMLGUI) << "cannot find .rc file" << _file << "for component" << componentName();
     }
 
     // make sure to merge the settings from any file specified by setLocalXMLFile()
@@ -283,7 +281,7 @@ void KXMLGUIClient::setLocalXMLFile(const QString &file)
 void KXMLGUIClient::replaceXMLFile(const QString &xmlfile, const QString &localxmlfile, bool merge)
 {
     if (!QDir::isAbsolutePath(xmlfile)) {
-        qWarning() << "xml file" << xmlfile << "is not an absolute path";
+        qCWarning(DEBUG_KXMLGUI) << "xml file" << xmlfile << "is not an absolute path";
     }
 
     setLocalXMLFile(localxmlfile);
@@ -297,7 +295,7 @@ void KXMLGUIClient::replaceXMLFile(const QString &xmlfile, const QString &localx
 // In order to preserve this semantics through document mergings,
 // the top or application domain must be propagated to all text elements
 // lacking their own domain attribute.
-static void propagateTranslationDomain(QDomDocument &doc, const QStringList tagNames)
+static void propagateTranslationDomain(QDomDocument &doc, const QStringList &tagNames)
 {
     const QLatin1String attrDomain("translationDomain");
     QDomElement base = doc.documentElement();
@@ -374,7 +372,7 @@ static inline bool equalstr(const QString &a, const QString &b)
 {
     return a.compare(b, Qt::CaseInsensitive) == 0;
 }
-static inline bool equalstr(const QString &a, const QLatin1String &b)
+static inline bool equalstr(const QString &a, QLatin1String b)
 {
     return a.compare(b, Qt::CaseInsensitive) == 0;
 }
@@ -405,9 +403,9 @@ bool KXMLGUIClientPrivate::mergeXML(QDomElement &base, QDomElement &additive, KA
         // Merge attributes
         {
             const QDomNamedNodeMap attribs = additive.attributes();
-            const uint attribcount = attribs.count();
+            const int attribcount = attribs.count();
 
-            for (uint i = 0; i < attribcount; ++i) {
+            for (int i = 0; i < attribcount; ++i) {
                 const QDomNode node = attribs.item(i);
                 base.setAttribute(node.nodeName(), node.nodeValue());
             }
