@@ -29,23 +29,24 @@
 #include "kmainwindow_p.h"
 #include "kmessagebox.h"
 #include "kactioncollection.h"
+#ifdef QT_DBUS_LIB
 #include "kmainwindowiface_p.h"
+#endif
 #include "ktoolbarhandler_p.h"
 #include "kxmlguifactory.h"
 #include "kedittoolbar.h"
 #include "khelpmenu.h"
 #include "ktoolbar.h"
 
-#include <QCloseEvent>
+#ifdef QT_DBUS_LIB
 #include <QDBusConnection>
+#endif
 #include <QDomDocument>
-#include <QLayout>
 #include <QMenuBar>
-#include <QObject>
 #include <QStatusBar>
-#include <QStyle>
 #include <QWidget>
 #include <QList>
+#include <QEvent>
 
 #include <ktoggleaction.h>
 #include <kstandardaction.h>
@@ -87,7 +88,9 @@ KXmlGuiWindow::KXmlGuiWindow(QWidget *parent, Qt::WindowFlags f)
     d->toolBarHandler = nullptr;
     d->showStatusBarAction = nullptr;
     d->factory = nullptr;
+#ifdef QT_DBUS_LIB
     new KMainWindowInterface(this);
+#endif
 }
 
 QAction *KXmlGuiWindow::toolBarMenuAction()
@@ -118,12 +121,14 @@ bool KXmlGuiWindow::event(QEvent *ev)
 {
     bool ret = KMainWindow::event(ev);
     if (ev->type() == QEvent::Polish) {
+#ifdef QT_DBUS_LIB
         QDBusConnection::sessionBus().registerObject(dbusName() + QStringLiteral("/actions"), actionCollection(),
                 QDBusConnection::ExportScriptableSlots |
                 QDBusConnection::ExportScriptableProperties |
                 QDBusConnection::ExportNonScriptableSlots |
                 QDBusConnection::ExportNonScriptableProperties |
                 QDBusConnection::ExportChildObjects);
+#endif
     }
     return ret;
 }
@@ -159,7 +164,8 @@ void KXmlGuiWindow::configureToolbars()
     if (!d->toolBarEditor) {
         d->toolBarEditor = new KEditToolBar(guiFactory(), this);
         d->toolBarEditor->setAttribute(Qt::WA_DeleteOnClose);
-        connect(d->toolBarEditor, SIGNAL(newToolBarConfig()), SLOT(saveNewToolbarConfig()));
+        connect(d->toolBarEditor, &KEditToolBar::newToolBarConfig,
+                this, &KXmlGuiWindow::saveNewToolbarConfig);
     }
     d->toolBarEditor->show();
 }
@@ -351,9 +357,10 @@ void KXmlGuiWindow::createStandardStatusBarAction()
 {
     K_D(KXmlGuiWindow);
     if (!d->showStatusBarAction) {
-        d->showStatusBarAction = KStandardAction::showStatusbar(this, SLOT(setSettingsDirty()), actionCollection());
+        d->showStatusBarAction = KStandardAction::showStatusbar(this, &KMainWindow::setSettingsDirty, actionCollection());
         QStatusBar *sb = statusBar(); // Creates statusbar if it doesn't exist already.
-        connect(d->showStatusBarAction, SIGNAL(toggled(bool)), sb, SLOT(setVisible(bool)));
+        connect(d->showStatusBarAction, &QAction::toggled,
+                sb, &QWidget::setVisible);
         d->showStatusBarAction->setChecked(sb->isHidden());
     } else {
         // If the language has changed, we'll need to grab the new text and whatsThis
